@@ -2,7 +2,7 @@
 setMethod("show", "LDEstimate",
     function(object){
        digits <- getOption("digits")
-       show(as(object,"Estimate"))
+       getMethod("show","Estimate")(object)
        if(getdistrModOption("show.details")!="minimal"){
         cat("Location:", object@location, "\n")
         cat("Dispersion:", object@dispersion, "\n")
